Actions, Resources, and Condition Keys for AWS Elemental MediaLive - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Elemental MediaLive.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS Elemental MediaLive

AWS Elemental MediaLive (service prefix: `medialive`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Elemental MediaLive
- Resources Defined by AWS Elemental MediaLive
- Condition Keys for AWS Elemental MediaLive

## Actions Defined by AWS Elemental MediaLive

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchUpdateSchedule | Grants permission to add and remove actions from a channel's schedule. | Write | channel* |  |
CreateChannel | Grants permission to create a channel | Tagging | channel* |  |
input* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInput | Grants permission to create an input | Tagging | input* |  |
input-security-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInputSecurityGroup | Grants permission to create an input security group | Tagging | input-security-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateTags | Grants permission to create tags for channels, inputs, input security groups, and reservations. | Tagging | channel |  |
input |  |
input-security-group |  |
reservation |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteChannel | Grants permission to delete a channel | Write | channel* |  |
DeleteInput | Grants permission to delete an input | Write | input* |  |
DeleteInputSecurityGroup | Grants permission to delete an input security group | Write | input-security-group* |  |
DeleteReservation | Grants permission to delete an expired reservation | Write | reservation* |  |
DeleteTags | Grants permission to delete tags from channels, inputs, input security groups, and reservations. | Tagging | channel |  |
input |  |
input-security-group |  |
reservation |  |
| aws:TagKeys |
DescribeChannel | Grants permission to get details about a channel | Read | channel* |  |
DescribeInput | Grants permission to describe an input | Read | input* |  |
DescribeInputSecurityGroup | Grants permission to describe an input security group | Read | input-security-group* |  |
DescribeOffering | Grants permission to get details about a reservation offering | Read | offering* |  |
DescribeReservation | Grants permission to get details about a reservation | Read | reservation* |  |
DescribeSchedule | Grants permission to view a list of actions scheduled on a channel. | Read | channel* |  |
ListChannels | Grants permission to list channels | List |  |  |
ListInputSecurityGroups | Grants permission to list input security groups | List |  |  |
ListInputs | Grants permission to list inputs | List |  |  |
ListOfferings | Grants permission to list reservation offerings | List |  |  |
ListReservations | Grants permission to list reservations | List |  |  |
ListTagsForResource | Grants permission to list tags for channels, inputs, input security groups, and reservations. | List | channel |  |
input |  |
input-security-group |  |
reservation |  |
PurchaseOffering | Grants permission to purchase a reservation offering | Tagging | offering* |  |
reservation* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
StartChannel | Grants permission to start a channel | Write | channel* |  |
StopChannel | Grants permission to stop a channel | Write | channel* |  |
UpdateChannel | Grants permission to update a channel | Write | channel* |  |
UpdateChannelClass | Grants permission to update the class of a channel | Write | channel* |  |
UpdateInput | Grants permission to update an input | Write | input* |  |
UpdateInputSecurityGroup | Grants permission to update an input security group | Write | input-security-group* |  |
UpdateReservation | Grants permission to update a reservation | Write | reservation* |  |

## Resources Defined by AWS Elemental MediaLive

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
channel | `arn:${Partition}:medialive:${Region}:${Account}:channel:*` | aws:ResourceTag/${TagKey}
input | `arn:${Partition}:medialive:${Region}:${Account}:input:*` | aws:ResourceTag/${TagKey}
input-security-group | `arn:${Partition}:medialive:${Region}:${Account}:inputSecurityGroup:*` | aws:ResourceTag/${TagKey}
reservation | `arn:${Partition}:medialive:${Region}:${Account}:reservation:*` | aws:ResourceTag/${TagKey}
offering | `arn:${Partition}:medialive:${Region}:${Account}:offering:*` |

## Condition Keys for AWS Elemental MediaLive

AWS Elemental MediaLive defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} |  | String
aws:ResourceTag/${TagKey} |  | String
aws:TagKeys |  | String

On this page:

- Actions Defined by AWS Elemental MediaLive
- Resources Defined by AWS Elemental MediaLive
- Condition Keys for AWS Elemental MediaLive

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more